@@ -1,15 +1,15 @@
 use crate::errors::{
     ErrorsExt, INVALID_REQUEST, MISSING_REQUEST, TOO_MANY_REQUESTS, TOO_MANY_REQUESTS_HINT,
 };
-use crate::utils::{parse_name_value_2_attr, Single};
+use crate::method::parse_request_attr;
+use crate::utils::Single;
 use syn::{Error, Result, TraitItemMethod};
 
 pub(crate) fn get_request(method: &TraitItemMethod) -> Result<(String, String)> {
     let attrs = &method.attrs;
-
     let single = attrs
         .iter()
-        .filter_map(|attr| parse_name_value_2_attr(attr, "request", "method", "path"))
+        .filter_map(parse_request_attr)
         .collect::<Single<_>>();
 
     match single {
